@@ -2,7 +2,7 @@ import subprocess
 import os
 
 
-def execute_on_all_nodes(command: str, timeout=None, debug=False):
+def execute_on_all_nodes(command: str, timeout=None, verbose=False):
     """
     Execute the given command on all nodes in the cluster
     via mpiexec.
@@ -16,8 +16,17 @@ def execute_on_all_nodes(command: str, timeout=None, debug=False):
         "1",
     ]
     args += command.split()
-    if debug:
-        print("Command: ", " ".join(args))
+
+    return execute_shell(args, timeout=timeout, verbose=verbose)
+
+
+def execute_shell(cmd, timeout, verbose=False):
+
+    if isinstance(cmd, str):
+        cmd = cmd.split()
+
+    if verbose:
+        print("Command: ", " ".join(cmd))
 
     stdout_ = ""
     stderr_ = ""
@@ -25,7 +34,7 @@ def execute_on_all_nodes(command: str, timeout=None, debug=False):
     timed_out = False
 
     try:
-        res = subprocess.run(args, capture_output=True, timeout=timeout)
+        res = subprocess.run(cmd, capture_output=True, timeout=timeout)
         stdout_ = res.stdout.decode("utf-8")
         stderr_ = res.stderr.decode("utf-8")
         returncode = res.returncode
